@@ -50,14 +50,21 @@ class WorkOrderIMileStoneAdapter(IMileStoneAdapter):
         return self.entity.order
 
     def initial_prevision_date(self):
-        """returns the initial expected end of the milestone"""
-        return date.today()
+        """returns the initial expected end of the milestone
+
+        Warning: not taken into accound WorkOrder transition/state.
+        """
+        return self.entity.end_date or date.today()
 
     def eta_date(self):
         """returns expected date of completion based on what remains
         to be done
+
+        Warning: not taken into accound WorkOrder transition/state.
         """
-        return date.today()
+        if not self.entity.end_date or date.today() > self.entity.end_date:
+            return date.today()
+        return self.entity.end_date
 
     def completion_date(self):
         """returns date on which the subtask has been completed"""
