@@ -1,7 +1,7 @@
 """template-specific forms/views/actions/components"""
 
-from cubicweb.selectors import is_instance
-from cubicweb.web import uicfg
+from cubicweb.predicates import is_instance
+from cubicweb.web.views import uicfg
 from cubicweb.web.views.ibreadcrumbs import IBreadCrumbsAdapter
 
 class WorkOrderIBreadCrumbsAdapter(IBreadCrumbsAdapter):
